Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1005)

Unified Diff: Source/core/rendering/RenderBlock.cpp

Issue 335963002: Change LayoutState to be stack-allocated (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Fix assert Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/rendering/RenderBlock.cpp
diff --git a/Source/core/rendering/RenderBlock.cpp b/Source/core/rendering/RenderBlock.cpp
index dc0f14ec6ecda468d513c4e42e3024e81d51eee7..e59fcc1d5f25ed1ad37ebc8b30876833393fb2ed 100644
--- a/Source/core/rendering/RenderBlock.cpp
+++ b/Source/core/rendering/RenderBlock.cpp
@@ -379,7 +379,7 @@ void RenderBlock::invalidateTreeAfterLayout(const RenderLayerModelObject& invali
// Take care of positioned objects. This is required as LayoutState keeps a single clip rect.
if (TrackedRendererListHashSet* positionedObjects = this->positionedObjects()) {
TrackedRendererListHashSet::iterator end = positionedObjects->end();
- LayoutStateMaintainer statePusher(*this, isTableRow() ? LayoutSize() : locationOffset());
+ LayoutState statePusher(*this, isTableRow() ? LayoutSize() : locationOffset());
esprehn 2014/06/13 23:25:26 we should really call these state not statePusher
leviw_travelin_and_unemployed 2014/06/13 23:46:16 Sure!
for (TrackedRendererListHashSet::iterator it = positionedObjects->begin(); it != end; ++it) {
RenderBox* box = *it;
@@ -1575,8 +1575,8 @@ bool RenderBlock::simplifiedLayout()
{
- // LayoutStateMaintainer needs this deliberate scope to pop before repaint
- LayoutStateMaintainer statePusher(*this, locationOffset());
+ // LayoutState needs this deliberate scope to pop before repaint
+ LayoutState statePusher(*this, locationOffset());
esprehn 2014/06/13 23:25:26 LayoutState state(...)
if (needsPositionedMovementLayout() && !tryLayoutDoingPositionedMovementOnly())
return false;

Powered by Google App Engine
This is Rietveld 408576698